pub enum ApprovalModeCliArg {
Untrusted,
OnRequest,
Never,
}Variants
Untrusted
Only run “trusted” commands (e.g. ls, cat, sed) without asking for user approval. Will escalate to the user if the model proposes a command that is not in the “trusted” set.
OnRequest
The model decides when to ask the user for approval.
Never
Never ask for user approval Execution failures are immediately returned to the model.