pub struct SharedCliOptions {
pub images: Vec<PathBuf>,
pub model: Option<String>,
pub oss: bool,
pub oss_provider: Option<String>,
pub config_profile_v2: Option<ProfileV2Name>,
pub sandbox_mode: Option<SandboxModeCliArg>,
pub dangerously_bypass_approvals_and_sandbox: bool,
pub bypass_hook_trust: bool,
pub cwd: Option<PathBuf>,
pub add_dir: Vec<PathBuf>,
}Fields
images: Vec<PathBuf>Optional image(s) to attach to the initial prompt.
model: Option<String>Model the agent should use.
oss: boolUse open-source provider.
oss_provider: Option<String>Specify which local provider to use (lmstudio or ollama). If not specified with –oss, will use config default or show selection.
config_profile_v2: Option<ProfileV2Name>Layer $CODEX_HOME/
sandbox_mode: Option<SandboxModeCliArg>Select the sandbox policy to use when executing model-generated shell commands.
dangerously_bypass_approvals_and_sandbox: boolSkip all confirmation prompts and execute commands without sandboxing. EXTREMELY DANGEROUS. Intended solely for running in environments that are externally sandboxed.
bypass_hook_trust: boolRun enabled hooks without requiring persisted hook trust for this invocation. DANGEROUS. Intended only for automation that already vets hook sources.
cwd: Option<PathBuf>Tell the agent to use the specified directory as its working root.
add_dir: Vec<PathBuf>Additional directories that should be writable alongside the primary workspace.
Implementations
pub fn inherit_exec_root_options(&mut self, root: &Self)
pub fn apply_subcommand_overrides(&mut self, subcommand: Self)